# XY plotting

Oscilloscopes generally plots time X-axis. They also provide and X-Y mode, where one input is plotted on the X-axis. This feature is used for showing lissajou's figures and also for measuring the phase difference of two input waveforms.

# Objective

Plot two signals in the X-Y mode and find out their phase difference. The phase difference is be generated by CR circuit.

# Procedure

- Make the connections as shown in the figure. Use 1kΩ and 1μF
- Note down the maximum value ymax and the y-intercept yint

The phase difference is given by the equation θ=sin− 1((yint)/(ymax))

# Discussion

There is an option to plot (A1-A2) against A2. In the above circuit, this plots the voltage across the capacitor against the voltage across the resistor.

- Select C= 1μF, R= 1kΩ and plot (A1-A2) vs A2.
- Adjust the frequency to make both voltages equal.